summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--kcron/ktapp.cpp44
-rw-r--r--kcron/ktapp.h4
-rw-r--r--kcron/ktprintopt.h2
-rw-r--r--kcron/kttask.cpp8
-rw-r--r--kcron/kttask.h4
-rw-r--r--kdat/KDatMainWindow.cpp6
-rw-r--r--kdat/KDatMainWindow.h6
-rw-r--r--kdat/TODO2
-rw-r--r--knetwortdeconf/knetwortdeconf/kaddknownhostdlg.ui2
-rw-r--r--knetwortdeconf/knetwortdeconf/knetwortdeconf.cpp16
-rw-r--r--knetwortdeconf/knetwortdeconf/knetwortdeconf.h10
-rw-r--r--knetwortdeconf/knetwortdeconf/knetwortdeconfdlg.ui8
-rw-r--r--knetwortdeconf/knetwortdeconf/knetwortdeconfigparser.cpp2
-rw-r--r--knetwortdeconf/knetwortdeconf/kselectdistrodlg.ui12
-rw-r--r--kpackage/CHANGES2
-rw-r--r--kpackage/debAptInterface.cpp12
-rw-r--r--kpackage/debAptInterface.h6
-rw-r--r--kpackage/findf.cpp2
-rw-r--r--kpackage/kpackage.cpp34
-rw-r--r--kpackage/kpackage.h26
-rw-r--r--kpackage/kplview.cpp14
-rw-r--r--kpackage/kplview.h4
-rw-r--r--kpackage/managementWidget.cpp8
-rw-r--r--kpackage/managementWidget.h16
-rw-r--r--kpackage/packageDisplay.cpp20
-rw-r--r--kpackage/packageDisplay.h6
-rw-r--r--kpackage/pkgInterface.cpp4
-rw-r--r--kpackage/pkgInterface.h8
-rw-r--r--kpackage/pkgOptions.cpp2
-rw-r--r--kpackage/pkgOptions.h4
-rw-r--r--ksysv/OldView.cpp24
-rw-r--r--ksysv/OldView.h18
-rw-r--r--ksysv/TopWidget.cpp26
-rw-r--r--ksysv/TopWidget.h26
-rw-r--r--ksysv/ksv_conf.cpp2
-rw-r--r--ksysv/ksvdraglist.cpp16
-rw-r--r--ksysv/ksvdraglist.h18
-rw-r--r--ksysv/ksvlookandfeel.cpp4
-rw-r--r--kuser/editGroup.cpp12
-rw-r--r--kuser/editGroup.h2
-rw-r--r--kuser/kgroupvw.cpp8
-rw-r--r--kuser/kgroupvw.h6
-rw-r--r--kuser/kuservw.cpp10
-rw-r--r--kuser/kuservw.h6
-rw-r--r--kuser/mainWidget.cpp22
-rw-r--r--kuser/mainWidget.h6
-rw-r--r--kuser/propdlg.cpp2
-rw-r--r--kuser/propdlg.h2
-rw-r--r--secpolicy/secpolicywin.cpp4
-rw-r--r--secpolicy/secpolicywin.h2
50 files changed, 255 insertions, 255 deletions
diff --git a/kcron/ktapp.h b/kcron/ktapp.h
index b4e1d38..5a00140 100644
--- a/kcron/ktapp.h
+++ b/kcron/ktapp.h
@@ -18,7 +18,7 @@
#include <kmainwindow.h>
-class KAction;
+class TDEAction;
class TQString;
class KTView;
class CTHost;
@@ -31,7 +31,7 @@ class CTHost;
* Provides main window handling, session management and keyboard
* acceleration.
*/
-class KTApp : public KMainWindow
+class KTApp : public TDEMainWindow
{
Q_OBJECT
diff --git a/kcron/ktprintopt.h b/kcron/ktprintopt.h
index bff1f6c..60ace3f 100644
--- a/kcron/ktprintopt.h
+++ b/kcron/ktprintopt.h
@@ -21,7 +21,7 @@
#include <tdeprint/kprintdialogpage.h>
class TQCheckBox;
-class KAccel;
+class TDEAccel;
/**
*Give the user the option to print the crontab file.
diff --git a/kcron/kttask.cpp b/kcron/kttask.cpp
index 8465d3d..d0ceabd 100644
--- a/kcron/kttask.cpp
+++ b/kcron/kttask.cpp
@@ -397,10 +397,10 @@ KTTask::KTTask(CTTask* _cttask, const TQString & _caption)
}
// key acceleration
- key_accel = new KAccel(this);
- key_accel->insert(KStdAccel::Open, TQT_TQOBJECT(this), TQT_SLOT(slotOK()));
- key_accel->insert(KStdAccel::Close, TQT_TQOBJECT(this), TQT_SLOT(slotCancel()));
- key_accel->insert(KStdAccel::Quit, TQT_TQOBJECT(this), TQT_SLOT(slotCancel()));
+ key_accel = new TDEAccel(this);
+ key_accel->insert(TDEStdAccel::Open, TQT_TQOBJECT(this), TQT_SLOT(slotOK()));
+ key_accel->insert(TDEStdAccel::Close, TQT_TQOBJECT(this), TQT_SLOT(slotCancel()));
+ key_accel->insert(TDEStdAccel::Quit, TQT_TQOBJECT(this), TQT_SLOT(slotCancel()));
key_accel->readSettings();
setFixedSize( minimumSize() );
diff --git a/kcron/kttask.h b/kcron/kttask.h
index 6d715bb..40d1f6e 100644
--- a/kcron/kttask.h
+++ b/kcron/kttask.h
@@ -21,7 +21,7 @@ class TQLineEdit;
class TQCheckBox;
class TQButtonGroup;
class TQPushButton;
-class KAccel;
+class TDEAccel;
class CTTask;
@@ -133,7 +133,7 @@ private:
* Key accelerator.
*/
- KAccel* key_accel;
+ TDEAccel* key_accel;
// Widgets.
diff --git a/kdat/KDatMainWindow.cpp b/kdat/KDatMainWindow.cpp
index c3056ef..44bcece 100644
--- a/kdat/KDatMainWindow.cpp
+++ b/kdat/KDatMainWindow.cpp
@@ -85,7 +85,7 @@ KDatMainWindow* KDatMainWindow::getInstance()
#define KDAT_HORIZONTAL_LAYOUT
KDatMainWindow::KDatMainWindow()
- : KMainWindow(0), _destroyed( FALSE )
+ : TDEMainWindow(0), _destroyed( FALSE )
{
#ifdef KDAT_HORIZONTAL_LAYOUT /* 2002-01-20 LEW */
resize( 600, 600 ); /* was 600 by 400 */
@@ -155,7 +155,7 @@ KDatMainWindow::KDatMainWindow()
TQString about = i18n( "KDat Version %1\n\nKDat is a tar-based tape archiver.\n\nCopyright (c) 1998-2000 Sean Vyain\nCopyright (c) 2001-2002 Lawrence Widman\nkdat@cardiothink.com" ).arg( KDAT_VERSION );
_menu->insertItem( i18n( "&Help" ), helpMenu( about ) );
- _toolbar = new KToolBar( this );
+ _toolbar = new TDEToolBar( this );
_toolbar->insertButton( *ImageCache::instance()->getTapeUnmounted(), 0, TQT_SIGNAL( clicked( int ) ), TQT_TQOBJECT(this), TQT_SLOT( fileMountTape() ), TRUE, i18n( "Mount/unmount tape" ) );
@@ -1028,7 +1028,7 @@ void KDatMainWindow::status( const TQString & msg )
void KDatMainWindow::show()
{
- KMainWindow::show();
+ TDEMainWindow::show();
hideInfo();
}
diff --git a/kdat/KDatMainWindow.h b/kdat/KDatMainWindow.h
index 76ae941..d893bdc 100644
--- a/kdat/KDatMainWindow.h
+++ b/kdat/KDatMainWindow.h
@@ -27,7 +27,7 @@
class KMenuBar;
class TQSplitter;
class KStatusBar;
-class KToolBar;
+class TDEToolBar;
class KTreeView;
class KTreeViewItem;
@@ -51,7 +51,7 @@ class TapeInfoWidget;
/**
* @short The KDat main window. Everything happens from here.
*/
-class KDatMainWindow : public KMainWindow {
+class KDatMainWindow : public TDEMainWindow {
Q_OBJECT
@@ -60,7 +60,7 @@ private:
KMenuBar* _menu;
TQPopupMenu* _fileMenu;
TQPopupMenu* _editMenu;
- KToolBar* _toolbar;
+ TDEToolBar* _toolbar;
KStatusBar* _statusBar;
TQSplitter* _panner;
KTreeView* _tree;
diff --git a/kdat/TODO b/kdat/TODO
index 4c1435b..407f6ca 100644
--- a/kdat/TODO
+++ b/kdat/TODO
@@ -122,7 +122,7 @@ Outstanding Bugs
change the names to hi22 kdat don't find them :-( In the
future there should be a set of 16x16, 22x22 and 32x32
toolbar icons, the menu and toolbar can then be created
- with the KAction class and XMLGUI and the toolbar menu will
+ with the TDEAction class and XMLGUI and the toolbar menu will
then have an effect :-)"
2002-01-23
diff --git a/knetwortdeconf/knetwortdeconf/kaddknownhostdlg.ui b/knetwortdeconf/knetwortdeconf/kaddknownhostdlg.ui
index 430b37e..ef47e58 100644
--- a/knetwortdeconf/knetwortdeconf/kaddknownhostdlg.ui
+++ b/knetwortdeconf/knetwortdeconf/kaddknownhostdlg.ui
@@ -157,7 +157,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="KListBox">
+ <widget class="TDEListBox">
<property name="name">
<cstring>klbAliases</cstring>
</property>
diff --git a/knetwortdeconf/knetwortdeconf/knetwortdeconfdlg.ui b/knetwortdeconf/knetwortdeconf/knetwortdeconfdlg.ui
index 4834ca4..fd6abad 100644
--- a/knetwortdeconf/knetwortdeconf/knetwortdeconfdlg.ui
+++ b/knetwortdeconf/knetwortdeconf/knetwortdeconfdlg.ui
@@ -104,7 +104,7 @@
</spacer>
</hbox>
</widget>
- <widget class="KListView">
+ <widget class="TDEListView">
<column>
<property name="text">
<string>Interface</string>
@@ -452,7 +452,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="KListBox">
+ <widget class="TDEListBox">
<property name="name">
<cstring>klbDomainServerList</cstring>
</property>
@@ -640,7 +640,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="KListView">
+ <widget class="TDEListView">
<column>
<property name="text">
<string>IP Address</string>
@@ -786,7 +786,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="KListView" row="0" column="0" rowspan="2" colspan="1">
+ <widget class="TDEListView" row="0" column="0" rowspan="2" colspan="1">
<column>
<property name="text">
<string>Name</string>
diff --git a/knetwortdeconf/knetwortdeconf/knetwortdeconfigparser.cpp b/knetwortdeconf/knetwortdeconf/knetwortdeconfigparser.cpp
index a9fa230..27d236a 100644
--- a/knetwortdeconf/knetwortdeconf/knetwortdeconfigparser.cpp
+++ b/knetwortdeconf/knetwortdeconf/knetwortdeconfigparser.cpp
@@ -1073,7 +1073,7 @@ TQString KNetworkConfigParser::getPlatformInfo(TQDomElement platform){
}
/** Shows the dialog with all the supported platforms by GST. */
void KNetworkConfigParser::showSupportedPlatformsDialogSlot(){
- KSelectDistroDlg* dialog = new KSelectDistroDlg(0, 0);
+ TDESelectDistroDlg* dialog = new TDESelectDistroDlg(0, 0);
for ( TQStringList::Iterator it = supportedPlatformsList.begin(); it != supportedPlatformsList.end(); ++it )
{
diff --git a/knetwortdeconf/knetwortdeconf/kselectdistrodlg.ui b/knetwortdeconf/knetwortdeconf/kselectdistrodlg.ui
index d1d04ee..5baaebb 100644
--- a/knetwortdeconf/knetwortdeconf/kselectdistrodlg.ui
+++ b/knetwortdeconf/knetwortdeconf/kselectdistrodlg.ui
@@ -1,8 +1,8 @@
<!DOCTYPE UI><UI version="3.3" stdsetdef="1">
-<class>KSelectDistroDlg</class>
+<class>TDESelectDistroDlg</class>
<widget class="KDialog">
<property name="name">
- <cstring>KSelectDistroDlg</cstring>
+ <cstring>TDESelectDistroDlg</cstring>
</property>
<property name="geometry">
<rect>
@@ -25,7 +25,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="KListBox" row="2" column="0" rowspan="1" colspan="4">
+ <widget class="TDEListBox" row="2" column="0" rowspan="1" colspan="4">
<property name="name">
<cstring>klbDistroList</cstring>
</property>
@@ -113,19 +113,19 @@
<connection>
<sender>kpbOk</sender>
<signal>clicked()</signal>
- <receiver>KSelectDistroDlg</receiver>
+ <receiver>TDESelectDistroDlg</receiver>
<slot>accept()</slot>
</connection>
<connection>
<sender>kpbCancel</sender>
<signal>clicked()</signal>
- <receiver>KSelectDistroDlg</receiver>
+ <receiver>TDESelectDistroDlg</receiver>
<slot>reject()</slot>
</connection>
<connection>
<sender>klbDistroList</sender>
<signal>doubleClicked(TQListBoxItem*)</signal>
- <receiver>KSelectDistroDlg</receiver>
+ <receiver>TDESelectDistroDlg</receiver>
<slot>accept()</slot>
</connection>
</connections>
diff --git a/kpackage/CHANGES b/kpackage/CHANGES
index 6385956..fd476ab 100644
--- a/kpackage/CHANGES
+++ b/kpackage/CHANGES
@@ -122,7 +122,7 @@ Fix dependency checking problem for uninstalling RPM packages
kpackage-1.2
------------
-Use KAccelMenu class to simplify configuring
+Use TDEAccelMenu class to simplify configuring
accelerators and allow accelerators to be set by typing the
key when the menu item is selected. The ' character is needed
to precede the keys. (with post KDE1.1 libraries)
diff --git a/kpackage/debAptInterface.cpp b/kpackage/debAptInterface.cpp
index bf922ea..c35013a 100644
--- a/kpackage/debAptInterface.cpp
+++ b/kpackage/debAptInterface.cpp
@@ -98,26 +98,26 @@ bool DEBAPT::isType(char *, const TQString &)
return false;
}
-void DEBAPT::makeMenu(KActionCollection* act)
+void DEBAPT::makeMenu(TDEActionCollection* act)
{
- updateM = new KAction( i18n("&Update"), TQString(),
+ updateM = new TDEAction( i18n("&Update"), TQString(),
0, this,
TQT_SLOT(updateS()), act, "debapt_update");
- upgradeM = new KAction( i18n("U&pgrade"), TQString(),
+ upgradeM = new TDEAction( i18n("U&pgrade"), TQString(),
0, this,
TQT_SLOT(upgradeS()), act, "debapt_upgrade");
- fixupM = new KAction( i18n("&Fixup"), TQString(),
+ fixupM = new TDEAction( i18n("&Fixup"), TQString(),
0, this,
TQT_SLOT(fixupS()), act, "debapt_fixup");
- fileM = new KAction( i18n("&Apt-File Update"), TQString(),
+ fileM = new TDEAction( i18n("&Apt-File Update"), TQString(),
0, this,
TQT_SLOT(fileS()), act, "debapt_file");
}
-void DEBAPT::setMenu(KActionCollection*, bool enable)
+void DEBAPT::setMenu(TDEActionCollection*, bool enable)
{
updateM->setEnabled(enable);
upgradeM->setEnabled(enable);
diff --git a/kpackage/debAptInterface.h b/kpackage/debAptInterface.h
index b5d89ee..933622b 100644
--- a/kpackage/debAptInterface.h
+++ b/kpackage/debAptInterface.h
@@ -59,10 +59,10 @@ public:
void listRemotePackages(TQPtrList<packageInfo> *pki);
TQStringList getFileList(packageInfo *p);
- KAction *updateM, *upgradeM, *fixupM, *fileM;
+ TDEAction *updateM, *upgradeM, *fixupM, *fileM;
- void makeMenu(KActionCollection* act);
- void setMenu(KActionCollection* act, bool enable);
+ void makeMenu(TDEActionCollection* act);
+ void setMenu(TDEActionCollection* act, bool enable);
TQStringList readApt();
TQStringList readAptS();
diff --git a/kpackage/findf.cpp b/kpackage/findf.cpp
index 6a333f8..6712d4b 100644
--- a/kpackage/findf.cpp
+++ b/kpackage/findf.cpp
@@ -70,7 +70,7 @@ FindF::FindF(TQWidget *parent)
TQLabel *valueLabel = new TQLabel(value, i18n("Find:"), frame1);
valueLabel->setAlignment( AlignRight );
- tab = new KListView(frame1, "tab");
+ tab = new TDEListView(frame1, "tab");
connect(tab, TQT_SIGNAL(selectionChanged ( TQListViewItem * )),
this, TQT_SLOT(search( TQListViewItem * )));
tab->addColumn(i18n("Installed"),18);
diff --git a/kpackage/kpackage.cpp b/kpackage/kpackage.cpp
index 310ae0e..37e7944 100644
--- a/kpackage/kpackage.cpp
+++ b/kpackage/kpackage.cpp
@@ -65,7 +65,7 @@ extern Opts *opts;
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
KPKG::KPKG(TDEConfig *_config)
- : KMainWindow(0)
+ : TDEMainWindow(0)
{
kpackage = new KPACKAGE(_config, this);
setCentralWidget(kpackage);
@@ -100,16 +100,16 @@ void KPKG::setupMenu()
actionCollection());
recent->loadEntries( config );
- pack_find = new KAction( i18n("Find &Package..."), "find",
- KStdAccel::shortcut(KStdAccel::Find), TQT_TQOBJECT(kpackage),
+ pack_find = new TDEAction( i18n("Find &Package..."), "find",
+ TDEStdAccel::shortcut(TDEStdAccel::Find), TQT_TQOBJECT(kpackage),
TQT_SLOT(find()), actionCollection(), "pack_find");
- pack_findf = new KAction( i18n("Find &File..."), "filefind",
+ pack_findf = new TDEAction( i18n("Find &File..."), "filefind",
0, TQT_TQOBJECT(kpackage),
TQT_SLOT(findf()), actionCollection(), "pack_findf");
- kpack_reload = new KAction( i18n("&Reload"), "reload",
- KStdAccel::shortcut(KStdAccel::Reload), TQT_TQOBJECT(kpackage),
+ kpack_reload = new TDEAction( i18n("&Reload"), "reload",
+ TDEStdAccel::shortcut(TDEStdAccel::Reload), TQT_TQOBJECT(kpackage),
TQT_SLOT(reload()), actionCollection(), "kpack_reload");
(void) KStdAction::quit(TQT_TQOBJECT(kpackage), TQT_SLOT(fileQuit()),
@@ -121,23 +121,23 @@ void KPKG::setupMenu()
pack_next = KStdAction::forward(TQT_TQOBJECT(kpackage->management->treeList), TQT_SLOT(next()),
actionCollection(),"pack_next");
- (void) (new KAction( i18n("&Expand Tree"), "ftout",
+ (void) (new TDEAction( i18n("&Expand Tree"), "ftout",
0, TQT_TQOBJECT(kpackage),
TQT_SLOT(expandTree()), actionCollection(), "kpack_expand"));
- (void) (new KAction( i18n("&Collapse Tree"), "ftin",
+ (void) (new TDEAction( i18n("&Collapse Tree"), "ftin",
0, TQT_TQOBJECT(kpackage),
TQT_SLOT(collapseTree()), actionCollection(), "kpack_collapse"));
- (void) (new KAction( i18n("Clear &Marked"), TQString(),
+ (void) (new TDEAction( i18n("Clear &Marked"), TQString(),
0, TQT_TQOBJECT(kpackage),
TQT_SLOT(clearMarked()), actionCollection(), "kpack_clear"));
- (void) (new KAction( i18n("Mark &All"), TQString(),
+ (void) (new TDEAction( i18n("Mark &All"), TQString(),
0, TQT_TQOBJECT(kpackage),
TQT_SLOT(markAll()), actionCollection(), "kpack_markall"));
- pack_install = new KAction( i18n("&Install"), TQString(),
+ pack_install = new TDEAction( i18n("&Install"), TQString(),
0, TQT_TQOBJECT(kpackage->management),
TQT_SLOT(installSingleClicked()), actionCollection(), "install_single");
@@ -145,7 +145,7 @@ void KPKG::setupMenu()
kpackage->management->setInstallAction(pack_install);
- pack_uninstall = new KAction( i18n("&Uninstall"), TQString(),
+ pack_uninstall = new TDEAction( i18n("&Uninstall"), TQString(),
0, TQT_TQOBJECT(kpackage->management),
TQT_SLOT(uninstallSingleClicked()), actionCollection(), "uninstall_single");
@@ -153,11 +153,11 @@ void KPKG::setupMenu()
kpackage->management->setUninstallAction(pack_uninstall);
- (void) (new KAction( i18n("&Install Marked"), TQString(),
+ (void) (new TDEAction( i18n("&Install Marked"), TQString(),
0, TQT_TQOBJECT(kpackage->management),
TQT_SLOT(installMultClicked()), actionCollection(), "install_marked"));
- (void) (new KAction( i18n("&Uninstall Marked"), TQString(),
+ (void) (new TDEAction( i18n("&Uninstall Marked"), TQString(),
0, TQT_TQOBJECT(kpackage->management),
TQT_SLOT(uninstallMultClicked()), actionCollection(), "uninstall_marked"));
@@ -170,15 +170,15 @@ void KPKG::setupMenu()
KStdAction::keyBindings( guiFactory(), TQT_SLOT(configureShortcuts()), actionCollection());
- (void) (new KAction( i18n("Configure &KPackage..."), "configure",
+ (void) (new TDEAction( i18n("Configure &KPackage..."), "configure",
0, TQT_TQOBJECT(this),
TQT_SLOT(setOptions()), actionCollection(), "kpack_options"));
- (void) (new KAction( i18n("Clear Package &Folder Cache"), TQString(),
+ (void) (new TDEAction( i18n("Clear Package &Folder Cache"), TQString(),
0, TQT_TQOBJECT(this),
TQT_SLOT(clearDCache()), actionCollection(), "clear_dcache"));
- (void) (new KAction( i18n("Clear &Package Cache"), TQString(),
+ (void) (new TDEAction( i18n("Clear &Package Cache"), TQString(),
0, TQT_TQOBJECT(this),
TQT_SLOT(clearPCache()), actionCollection(), "clear_pcache"));
diff --git a/kpackage/kpackage.h b/kpackage/kpackage.h
index c552b81..216ad22 100644
--- a/kpackage/kpackage.h
+++ b/kpackage/kpackage.h
@@ -50,10 +50,10 @@ class FindF;
class Options;
class pkgInterface;
class managementWidget;
-class KAccel;
+class TDEAccel;
class TQDropEevnt;
-class KRecentFilesAction;
-class KAction;
+class TDERecentFilesAction;
+class TDEAction;
class kpRun;
#define kpinterfaceN 7
@@ -220,7 +220,7 @@ private:
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
-class KPKG : public KMainWindow
+class KPKG : public TDEMainWindow
{
Q_OBJECT
@@ -277,14 +277,14 @@ private:
TQStrList recent_files;
- KAction *pack_open;
- KAction *pack_find;
- KAction *pack_findf;
- KAction *kpack_reload;
- KAction *pack_prev;
- KAction *pack_next;
- KAction *pack_install;
- KAction *pack_uninstall;
+ TDEAction *pack_open;
+ TDEAction *pack_find;
+ TDEAction *pack_findf;
+ TDEAction *kpack_reload;
+ TDEAction *pack_prev;
+ TDEAction *pack_next;
+ TDEAction *pack_install;
+ TDEAction *pack_uninstall;
int toolID, selectID;
// refrences to toolbar and menu items
@@ -292,7 +292,7 @@ private:
bool hide_toolbar;
// don't display toolbar
- KRecentFilesAction *recent;
+ TDERecentFilesAction *recent;
public slots:
diff --git a/kpackage/kplview.cpp b/kpackage/kplview.cpp
index b5ca8f1..afd03f0 100644
--- a/kpackage/kplview.cpp
+++ b/kpackage/kplview.cpp
@@ -44,7 +44,7 @@
#define MPOS 1
KpTreeList::KpTreeList( TQWidget *parent ) :
-KListView (parent)
+TDEListView (parent)
{
markPkg = 0;
setShowSortIndicator(true);
@@ -80,17 +80,17 @@ void KpTreeList::clear()
{
markPkg = 0;
emit cleared();
- KListView::clear();
+ TDEListView::clear();
}
KpTreeListItem *KpTreeList::firstChild()
{
- return (KpTreeListItem *)KListView::firstChild();
+ return (KpTreeListItem *)TDEListView::firstChild();
}
KpTreeListItem *KpTreeList::currentItem()
{
- return (KpTreeListItem *)KListView::currentItem();
+ return (KpTreeListItem *)TDEListView::currentItem();
}
void KpTreeList::contentsMousePressEvent ( TQMouseEvent * e )
@@ -136,9 +136,9 @@ void KpTreeList::contentsMousePressEvent ( TQMouseEvent * e )
}
setCurrentItem(i);
} else
- KListView::contentsMousePressEvent (e);
+ TDEListView::contentsMousePressEvent (e);
} else
- KListView::contentsMousePressEvent (e);
+ TDEListView::contentsMousePressEvent (e);
}
if (markUpdate)
@@ -588,7 +588,7 @@ KpTreeListItem::KpTreeListItem( TQListViewItem *parent, packageInfo* pinfo,
setPixmap(1,info->interface->markUnInst);
}
-KpTreeListItem::KpTreeListItem( KListView *parent, packageInfo* pinfo,
+KpTreeListItem::KpTreeListItem( TDEListView *parent, packageInfo* pinfo,
const TQPixmap& thePixmap,
TQString label1, TQString label2 ,
TQString label3 , TQString label4 ,
diff --git a/kpackage/kplview.h b/kpackage/kplview.h
index 936f512..239e743 100644
--- a/kpackage/kplview.h
+++ b/kpackage/kplview.h
@@ -47,7 +47,7 @@
class packageDisplayWidget;
////////////////////////////////////////////////////////////////////////
-class KpTreeList: public KListView
+class KpTreeList: public TDEListView
{
Q_OBJECT
@@ -164,7 +164,7 @@ public:
TQString label7 = 0, TQString label8 = 0);
- KpTreeListItem( KListView *parent, packageInfo* pinfo,
+ KpTreeListItem( TDEListView *parent, packageInfo* pinfo,
const TQPixmap& thePixmap,
TQString label1 = 0, TQString label2 = 0,
TQString label3 = 0, TQString label4 = 0,
diff --git a/kpackage/managementWidget.cpp b/kpackage/managementWidget.cpp
index b50dcee..958b901 100644
--- a/kpackage/managementWidget.cpp
+++ b/kpackage/managementWidget.cpp
@@ -53,7 +53,7 @@
extern Opts *opts;
KpListViewSearchLine::KpListViewSearchLine(TQWidget *parent, KpTreeList *listView)
- :KListViewSearchLine(parent, listView)
+ :TDEListViewSearchLine(parent, listView)
{
list = listView;
}
@@ -65,8 +65,8 @@ KpListViewSearchLine::~KpListViewSearchLine()
void KpListViewSearchLine::updateSearch(const TQString &s)
{
list->expand();
- KListViewSearchLine::updateSearch(s);
- KListViewSearchLine::updateSearch(s); // Yes both are needed
+ TDEListViewSearchLine::updateSearch(s);
+ TDEListViewSearchLine::updateSearch(s); // Yes both are needed
list->sweep(false);
}
@@ -132,7 +132,7 @@ void managementWidget::setupWidgets()
ltab->addTab(t);
}
// Quick Search Bar
- searchToolBar = new KToolBar( leftpanel, "search toolbar");
+ searchToolBar = new TDEToolBar( leftpanel, "search toolbar");
TQToolButton *clearSearch = new TQToolButton(searchToolBar);
clearSearch->setTextLabel(i18n("Clear Search"), true);
diff --git a/kpackage/managementWidget.h b/kpackage/managementWidget.h
index 3eeb236..f681fc0 100644
--- a/kpackage/managementWidget.h
+++ b/kpackage/managementWidget.h
@@ -64,11 +64,11 @@
class packageDisplayWidget;
class packageInfo;
class TQSplitter;
-class KActionCollection;
-class KToolBar;
+class TDEActionCollection;
+class TDEToolBar;
class managementWidget;
-class KpListViewSearchLine : public KListViewSearchLine
+class KpListViewSearchLine : public TDEListViewSearchLine
{
Q_OBJECT
@@ -156,8 +156,8 @@ private:
void installMultClicked();
// This is called when the install button has been clicked with multiple packages
- void setInstallAction(KAction *a) { install_action = a; }
- void setUninstallAction(KAction *a) { uninstall_action = a; }
+ void setInstallAction(TDEAction *a) { install_action = a; }
+ void setUninstallAction(TDEAction *a) { uninstall_action = a; }
void packageHighlighted(TQListViewItem *);
// This is called when a package has been highlighted in the list tree
@@ -192,7 +192,7 @@ private:
TQSplitter *vPan;
// veritcal panner between panels
- KToolBar *searchToolBar;
+ TDEToolBar *searchToolBar;
TQPtrList<KpTreeListItem> selList;
// list for selected packages
@@ -219,8 +219,8 @@ public:
KpListViewSearchLine *searchLine;
// Widget for search treeList
- KAction *install_action;
- KAction *uninstall_action;
+ TDEAction *install_action;
+ TDEAction *uninstall_action;
};
#endif
diff --git a/kpackage/packageDisplay.cpp b/kpackage/packageDisplay.cpp
index 8941327..f416f21 100644
--- a/kpackage/packageDisplay.cpp
+++ b/kpackage/packageDisplay.cpp
@@ -181,8 +181,8 @@ void packageDisplayWidget::changePackage(packageInfo *p)
this, TQT_SLOT( openBinding(TQListViewItem *)) );
disconnect(fileList, TQT_SIGNAL(returnPressed(TQListViewItem *)),
this, TQT_SLOT( openBinding(TQListViewItem *)) );
- disconnect(fileList, TQT_SIGNAL(contextMenu(KListView *, TQListViewItem *, const TQPoint &)),
- fileList, TQT_SLOT( openContext(KListView *, TQListViewItem *, const TQPoint &)) );
+ disconnect(fileList, TQT_SIGNAL(contextMenu(TDEListView *, TQListViewItem *, const TQPoint &)),
+ fileList, TQT_SLOT( openContext(TDEListView *, TQListViewItem *, const TQPoint &)) );
if (package && package != p) {
@@ -234,8 +234,8 @@ void packageDisplayWidget::changePackage(packageInfo *p)
this, TQT_SLOT( openBinding(TQListViewItem *)) );
connect(fileList, TQT_SIGNAL(returnPressed(TQListViewItem *)),
this, TQT_SLOT( openBinding(TQListViewItem *)) );
- connect(fileList, TQT_SIGNAL(contextMenu(KListView *, TQListViewItem *, const TQPoint &)),
- fileList, TQT_SLOT( openContext(KListView *, TQListViewItem *, const TQPoint &)) );
+ connect(fileList, TQT_SIGNAL(contextMenu(TDEListView *, TQListViewItem *, const TQPoint &)),
+ fileList, TQT_SLOT( openContext(TDEListView *, TQListViewItem *, const TQPoint &)) );
}
@@ -363,15 +363,15 @@ void packageDisplayWidget::updateFileList()
kpackage->setPercent(100);
}
- kpFileList::kpFileList(TQWidget* parent, packageDisplayWidget* parent2) : KListView(parent)
+ kpFileList::kpFileList(TQWidget* parent, packageDisplayWidget* parent2) : TDEListView(parent)
{
hide();
addColumn("name");
setRootIsDecorated(TRUE);
- connect(this, TQT_SIGNAL(contextMenu(KListView *, TQListViewItem *, const TQPoint &)),
- this, TQT_SLOT( openContext(KListView *, TQListViewItem *, const TQPoint &)) );
+ connect(this, TQT_SIGNAL(contextMenu(TDEListView *, TQListViewItem *, const TQPoint &)),
+ this, TQT_SLOT( openContext(TDEListView *, TQListViewItem *, const TQPoint &)) );
- FileListMenu = new KPopupMenu();
+ FileListMenu = new TDEPopupMenu();
openwith = FileListMenu->insertItem(i18n("&Open With..."),parent2,TQT_SLOT(__openBindingWith()));
pkDisplay = parent2;
@@ -394,7 +394,7 @@ void packageDisplayWidget::updateFileList()
}
- void kpFileList::openContext(KListView *, TQListViewItem *, const TQPoint &p)
+ void kpFileList::openContext(TDEListView *, TQListViewItem *, const TQPoint &p)
{
FileListMenu->setItemEnabled(openwith,
(selectedItem() && pkDisplay->package && pkDisplay->package->getFilename().isEmpty()) ? TRUE : FALSE);
@@ -404,7 +404,7 @@ void packageDisplayWidget::updateFileList()
void kpFileList::clear()
{
- KListView::clear();
+ TDEListView::clear();
}
TQString kpFileList::item2Path(TQListViewItem *it)
diff --git a/kpackage/packageDisplay.h b/kpackage/packageDisplay.h
index efd9949..091e031 100644
--- a/kpackage/packageDisplay.h
+++ b/kpackage/packageDisplay.h
@@ -54,7 +54,7 @@ class packageInfo;
class TQListViewItem;
class TQTextEdit;
class packageDisplayWidget;
-class kpFileList : public KListView
+class kpFileList : public TDEListView
{
Q_OBJECT
@@ -68,7 +68,7 @@ public:
public slots:
- void openContext(KListView *, TQListViewItem *, const TQPoint &);
+ void openContext(TDEListView *, TQListViewItem *, const TQPoint &);
virtual void clear();
@@ -76,7 +76,7 @@ public slots:
private:
- KPopupMenu *FileListMenu;
+ TDEPopupMenu *FileListMenu;
packageDisplayWidget* pkDisplay;
int openwith;
diff --git a/kpackage/pkgInterface.cpp b/kpackage/pkgInterface.cpp
index 984628d..f5f31dc 100644
--- a/kpackage/pkgInterface.cpp
+++ b/kpackage/pkgInterface.cpp
@@ -91,11 +91,11 @@ pkgInterface::~pkgInterface()
}
//////////////////////////////////////////////////////////////////////////////
-void pkgInterface::makeMenu(KActionCollection *)
+void pkgInterface::makeMenu(TDEActionCollection *)
{
}
-void pkgInterface::setMenu(KActionCollection*, bool )
+void pkgInterface::setMenu(TDEActionCollection*, bool )
{
}
diff --git a/kpackage/pkgInterface.h b/kpackage/pkgInterface.h
index 5b39aa0..8b4c779 100644
--- a/kpackage/pkgInterface.h
+++ b/kpackage/pkgInterface.h
@@ -44,8 +44,8 @@ class pkgOptions;
class Locations;
class LcacheObj;
class cacheObj;
-class KAccel;
-class KActionCollection;
+class TDEAccel;
+class TDEActionCollection;
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
@@ -78,8 +78,8 @@ public:
virtual bool isType(char *buf, const TQString &fname) = 0;
// looks at start of file to check that package is correct type
- virtual void makeMenu(KActionCollection* act);
- virtual void setMenu(KActionCollection* act, bool enable);
+ virtual void makeMenu(TDEActionCollection* act);
+ virtual void setMenu(TDEActionCollection* act, bool enable);
bool ifExe(TQString exe);
// Check if this executable exists
diff --git a/kpackage/pkgOptions.cpp b/kpackage/pkgOptions.cpp
index 4c68366..d7c3fc1 100644
--- a/kpackage/pkgOptions.cpp
+++ b/kpackage/pkgOptions.cpp
@@ -112,7 +112,7 @@ void pkgOptions::setupWidgets(TQPtrList<param> &pars)
{
layout = new TQBoxLayout(hlayout,TQBoxLayout::TopToBottom, spacingHint());
- packages = new KListView(this);
+ packages = new TDEListView(this);
layout->addWidget(packages,20);
packages->addColumn(i18n("PACKAGES"),200);
diff --git a/kpackage/pkgOptions.h b/kpackage/pkgOptions.h
index 54ac2c8..1d93708 100644
--- a/kpackage/pkgOptions.h
+++ b/kpackage/pkgOptions.h
@@ -46,7 +46,7 @@
#include "pkgInterface.h"
#include "kpTerm.h"
-class KListView;
+class TDEListView;
class KPushButton;
class pkgOptions : public KDialog
@@ -70,7 +70,7 @@ public:
TQCheckBox *Keep;
// keep window
- KListView *packages;
+ TDEListView *packages;
int bnumber;
// number of option buttons
diff --git a/ksysv/OldView.cpp b/ksysv/OldView.cpp
index dbacbe6..2735861 100644
--- a/ksysv/OldView.cpp
+++ b/ksysv/OldView.cpp
@@ -72,7 +72,7 @@
#include "ActionList.h"
#include "TopWidget.h"
-KSVContent::KSVContent (KPopupMenu* openWithMenu, KSVTopLevel* parent, const char* name)
+KSVContent::KSVContent (TDEPopupMenu* openWithMenu, KSVTopLevel* parent, const char* name)
: TQSplitter (Qt::Vertical, parent, name),
startRL (new KSVDragList*[ksv::runlevelNumber]),
stopRL (new KSVDragList*[ksv::runlevelNumber]),
@@ -85,11 +85,11 @@ KSVContent::KSVContent (KPopupMenu* openWithMenu, KSVTopLevel* parent, const cha
setOpaqueResize( TDEGlobalSettings::opaqueResize() );
KXMLGUIFactory* factory = parent->factory();
- mItemMenu = static_cast<KPopupMenu*> (factory->container ("item_menu", parent));
+ mItemMenu = static_cast<TDEPopupMenu*> (factory->container ("item_menu", parent));
mItemMenu->insertTitle (i18n ("Runlevel Menu"), -1, 0);
- mContextMenu = static_cast<KPopupMenu*> (factory->container ("list_menu", parent));
+ mContextMenu = static_cast<TDEPopupMenu*> (factory->container ("list_menu", parent));
mContextMenu->insertTitle (i18n ("Runlevel Menu"), -1, 0);
- mScriptMenu = static_cast<KPopupMenu*> (factory->container ("script_menu", parent));
+ mScriptMenu = static_cast<TDEPopupMenu*> (factory->container ("script_menu", parent));
mScriptMenu->insertTitle (i18n ("Services Menu"), -1, 0);
mScroller = new KScroller (this);
@@ -225,8 +225,8 @@ void KSVContent::initLList()
this, TQT_SLOT (slotScriptProperties (TQListViewItem*)));
// context menus
- connect (scripts, TQT_SIGNAL (contextMenu (KListView*, TQListViewItem*, const TQPoint&)),
- this, TQT_SLOT (popupServicesMenu (KListView*, TQListViewItem*, const TQPoint&)));
+ connect (scripts, TQT_SIGNAL (contextMenu (TDEListView*, TQListViewItem*, const TQPoint&)),
+ this, TQT_SLOT (popupServicesMenu (TDEListView*, TQListViewItem*, const TQPoint&)));
// for cut & copy
connect (scripts, TQT_SIGNAL (newOrigin ()),
@@ -332,10 +332,10 @@ void KSVContent::initLList()
this, TQT_SLOT(slotDoubleClick(TQListViewItem*)));
// context menus
- connect (startRL[i], TQT_SIGNAL (contextMenu (KListView*, TQListViewItem*, const TQPoint&)),
- this, TQT_SLOT (popupRunlevelMenu (KListView*, TQListViewItem*, const TQPoint&)));
- connect (stopRL[i], TQT_SIGNAL (contextMenu (KListView*, TQListViewItem*, const TQPoint&)),
- this, TQT_SLOT (popupRunlevelMenu (KListView*, TQListViewItem*, const TQPoint&)));
+ connect (startRL[i], TQT_SIGNAL (contextMenu (TDEListView*, TQListViewItem*, const TQPoint&)),
+ this, TQT_SLOT (popupRunlevelMenu (TDEListView*, TQListViewItem*, const TQPoint&)));
+ connect (stopRL[i], TQT_SIGNAL (contextMenu (TDEListView*, TQListViewItem*, const TQPoint&)),
+ this, TQT_SLOT (popupRunlevelMenu (TDEListView*, TQListViewItem*, const TQPoint&)));
// cannot generate sorting number
connect (startRL[i], TQT_SIGNAL(cannotGenerateNumber()),
@@ -994,7 +994,7 @@ void KSVContent::showRunlevel (int index)
calcMinSize();
}
-void KSVContent::popupRunlevelMenu (KListView* list, TQListViewItem* i, const TQPoint& p)
+void KSVContent::popupRunlevelMenu (TDEListView* list, TQListViewItem* i, const TQPoint& p)
{
if (i)
mItemMenu->exec (p, 1);
@@ -1005,7 +1005,7 @@ void KSVContent::popupRunlevelMenu (KListView* list, TQListViewItem* i, const TQ
}
}
-void KSVContent::popupServicesMenu (KListView*, TQListViewItem* i, const TQPoint& p)
+void KSVContent::popupServicesMenu (TDEListView*, TQListViewItem* i, const TQPoint& p)
{
if (i)
{
diff --git a/ksysv/OldView.h b/ksysv/OldView.h
index c71b995..53eeb7a 100644
--- a/ksysv/OldView.h
+++ b/ksysv/OldView.h
@@ -33,9 +33,9 @@ class TQLayout;
class KScroller;
class TDEProcess;
-class KListView;
+class TDEListView;
class TQSplitter;
-class KPopupMenu;
+class TDEPopupMenu;
class KSVTrash;
class KSVDragList;
class KSVConfig;
@@ -50,7 +50,7 @@ class KSVContent : public TQSplitter
public:
- KSVContent (KPopupMenu* openWithMenu, KSVTopLevel* parent = 0, const char* name = 0);
+ KSVContent (TDEPopupMenu* openWithMenu, KSVTopLevel* parent = 0, const char* name = 0);
~KSVContent();
KSVDragList* getOrigin();
@@ -107,8 +107,8 @@ private slots:
void fwdUndoAction(KSVAction*);
void updatePanningFactor();
- void popupRunlevelMenu (KListView*, TQListViewItem*, const TQPoint&);
- void popupServicesMenu (KListView*, TQListViewItem*, const TQPoint&);
+ void popupRunlevelMenu (TDEListView*, TQListViewItem*, const TQPoint&);
+ void popupServicesMenu (TDEListView*, TQListViewItem*, const TQPoint&);
void updateServicesAfterChange (const TQString&);
void updateRunlevelsAfterChange ();
@@ -154,9 +154,9 @@ private:
KSVDragList** stopRL;
KSVDragList* scripts;
- KPopupMenu* mItemMenu;
- KPopupMenu* mContextMenu;
- KPopupMenu* mScriptMenu;
+ TDEPopupMenu* mItemMenu;
+ TDEPopupMenu* mContextMenu;
+ TDEPopupMenu* mScriptMenu;
KSVTrash* trash;
TQTextEdit* textDisplay;
KSVConfig* conf;
@@ -171,7 +171,7 @@ private:
TQSize mMinSize;
- KPopupMenu* mOpenWithMenu;
+ TDEPopupMenu* mOpenWithMenu;
TDETrader::OfferList mOpenWithOffers;
TQCString m_buffer;
diff --git a/ksysv/TopWidget.cpp b/ksysv/TopWidget.cpp
index 4724eb7..67f8404 100644
--- a/ksysv/TopWidget.cpp
+++ b/ksysv/TopWidget.cpp
@@ -95,7 +95,7 @@ namespace Status
} // namespace Status
KSVTopLevel::KSVTopLevel()
- : KMainWindow(0, 0L, WStyle_ContextHelp|WDestructiveClose),
+ : TDEMainWindow(0, 0L, WStyle_ContextHelp|WDestructiveClose),
mConfig(KSVConfig::self()),
mView (0L),
mPreferences (0L),
@@ -208,7 +208,7 @@ void KSVTopLevel::initTools()
void KSVTopLevel::initActions ()
{
- KActionCollection* coll = actionCollection();
+ TDEActionCollection* coll = actionCollection();
// setup File menu
mFileRevert = KStdAction::revert (TQT_TQOBJECT(this), TQT_SLOT (slotClearChanges()), coll);
@@ -247,15 +247,15 @@ void KSVTopLevel::initActions ()
mPasteAppend = KStdAction::paste (TQT_TQOBJECT(this), TQT_SLOT (pasteAppend()),
coll, "ksysv_paste_append");
- mEditProperties = new KAction (i18n("P&roperties"), 0,
+ mEditProperties = new TDEAction (i18n("P&roperties"), 0,
TQT_TQOBJECT(this), TQT_SLOT(properties()),
coll, "ksysv_properties");
- mOpenDefault = new KAction (i18n ("&Open"), 0,
+ mOpenDefault = new TDEAction (i18n ("&Open"), 0,
TQT_TQOBJECT(this), TQT_SLOT (editService()),
coll, "ksysv_open_service");
- mOpenWith = new KActionMenu (i18n ("Open &With"), coll, "ksysv_open_with");
+ mOpenWith = new TDEActionMenu (i18n ("Open &With"), coll, "ksysv_open_with");
// setup Settings menu
createStandardStatusBarAction();
@@ -264,25 +264,25 @@ void KSVTopLevel::initActions ()
KStdAction::configureToolbars (TQT_TQOBJECT(this), TQT_SLOT(configureToolbars()), coll);
KStdAction::saveOptions(TQT_TQOBJECT(this), TQT_SLOT(saveOptions()), coll);
KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(slotShowConfig()), coll);
- mOptionsToggleLog = new KToggleAction (i18n("Show &Log"), "toggle_log", 0,
+ mOptionsToggleLog = new TDEToggleAction (i18n("Show &Log"), "toggle_log", 0,
TQT_TQOBJECT(this), TQT_SLOT (toggleLog()),
coll, "ksysv_toggle_log");
mOptionsToggleLog->setCheckedState(i18n("Hide &Log"));
// setup Tools menu
- mToolsStartService = new KToggleAction (i18n("&Start Service..."), "ksysv_start", 0,
+ mToolsStartService = new TDEToggleAction (i18n("&Start Service..."), "ksysv_start", 0,
TQT_TQOBJECT(mStartDlg), TQT_SLOT (toggle()),
coll, "ksysv_start_service");
- mToolsStopService = new KToggleAction (i18n("&Stop Service..."), "ksysv_stop", 0,
+ mToolsStopService = new TDEToggleAction (i18n("&Stop Service..."), "ksysv_stop", 0,
TQT_TQOBJECT(mStopDlg), TQT_SLOT (toggle()),
coll, "ksysv_stop_service");
- mToolsRestartService = new KToggleAction (i18n("&Restart Service..."), 0,
+ mToolsRestartService = new TDEToggleAction (i18n("&Restart Service..."), 0,
TQT_TQOBJECT(mRestartDlg), TQT_SLOT (toggle()),
coll, "ksysv_restart_service");
- mToolsEditService = new KToggleAction (i18n("&Edit Service..."), 0,
+ mToolsEditService = new TDEToggleAction (i18n("&Edit Service..."), 0,
TQT_TQOBJECT(mEditDlg), TQT_SLOT (toggle()),
coll, "ksysv_edit_service");
@@ -851,7 +851,7 @@ void KSVTopLevel::closeEvent (TQCloseEvent* e)
return;
}
- KMainWindow::closeEvent (e);
+ TDEMainWindow::closeEvent (e);
}
void KSVTopLevel::dispatchEdit ()
@@ -957,10 +957,10 @@ void KSVTopLevel::setCaption (bool changed)
setPlainCaption (kapp->makeStdCaption(KNetwork::KResolver::localHostName(), true, changed));
}
-KActionCollection* KSVTopLevel::filteredActions ()
+TDEActionCollection* KSVTopLevel::filteredActions ()
{
// remove unwanted (internal) actions
- static KActionCollection coll = *actionCollection();
+ static TDEActionCollection coll = *actionCollection();
static bool initialized = false;
if (!initialized)
diff --git a/ksysv/TopWidget.h b/ksysv/TopWidget.h
index 8e5687b..2cf56b0 100644
--- a/ksysv/TopWidget.h
+++ b/ksysv/TopWidget.h
@@ -19,13 +19,13 @@
class TQCheckBox;
-class KAction;
-class KToggleAction;
-class KActionMenu;
+class TDEAction;
+class TDEToggleAction;
+class TDEActionMenu;
class KMenuBar;
class KStatusBar;
-class KToolBar;
-class KActionCollection;
+class TDEToolBar;
+class TDEActionCollection;
class ActionList;
class KSVAction;
@@ -36,7 +36,7 @@ class KSVContent;
class KSVPreferences;
class RunlevelAuthIcon;
-class KSVTopLevel : public KMainWindow
+class KSVTopLevel : public TDEMainWindow
{
Q_OBJECT
@@ -55,7 +55,7 @@ protected:
void initActions ();
void initStatusBar();
- KActionCollection* filteredActions ();
+ TDEActionCollection* filteredActions ();
private slots:
void slotClearChanges();
@@ -122,19 +122,19 @@ private:
KSVPreferences* mPreferences;
- KAction *mEditUndo, *mEditRedo, *mEditCut, *mEditCopy, *mEditPaste,
+ TDEAction *mEditUndo, *mEditRedo, *mEditCut, *mEditCopy, *mEditPaste,
*mPasteAppend, *mEditProperties;
- KAction *mFileRevert, *mFileLoad, *mFilePrint, *mFilePrintLog,
+ TDEAction *mFileRevert, *mFileLoad, *mFilePrint, *mFilePrintLog,
*mFileSave, *mFileSaveAs, *mFileSaveLog, *mFileQuit;
- KToggleAction *mToolsStartService, *mToolsStopService,
+ TDEToggleAction *mToolsStartService, *mToolsStopService,
*mToolsRestartService, *mToolsEditService;
- KToggleAction *mOptionsToggleLog;
+ TDEToggleAction *mOptionsToggleLog;
- KActionMenu* mOpenWith;
- KAction* mOpenDefault;
+ TDEActionMenu* mOpenWith;
+ TDEAction* mOpenDefault;
bool mChanged;
diff --git a/ksysv/ksv_conf.cpp b/ksysv/ksv_conf.cpp
index 37a24ee..1939d57 100644
--- a/ksysv/ksv_conf.cpp
+++ b/ksysv/ksv_conf.cpp
@@ -101,7 +101,7 @@ void KSVConfig::writeSettings() {
mConfig->writeEntry("Number Font", mNumberFont);
// save screen geometry
- KMainWindow* mw = static_cast<KMainWindow*>(kapp->mainWidget());
+ TDEMainWindow* mw = static_cast<TDEMainWindow*>(kapp->mainWidget());
if (mw)
{
diff --git a/ksysv/ksvdraglist.cpp b/ksysv/ksvdraglist.cpp
index 65a1b3e..3edaaf0 100644
--- a/ksysv/ksvdraglist.cpp
+++ b/ksysv/ksvdraglist.cpp
@@ -57,7 +57,7 @@
#include "ksvdrag.h"
#include "ActionList.h"
-KSVItem::KSVItem (KListView* view)
+KSVItem::KSVItem (TDEListView* view)
: TQListViewItem (view),
mData (new KSVData()),
mConfig (KSVConfig::self()),
@@ -110,7 +110,7 @@ TQString KSVItem::key (int, bool) const
return mData->numberString() + mData->label();
}
-KSVItem::KSVItem (KListView* view, TQString file, TQString path, TQString label, TQ_INT8 nr )
+KSVItem::KSVItem (TDEListView* view, TQString file, TQString path, TQString label, TQ_INT8 nr )
: TQListViewItem (view),
mData (new KSVData (file, path, label, nr)),
mConfig (KSVConfig::self()),
@@ -310,11 +310,11 @@ void KSVItem::setOriginalRunlevel (const TQString& rl)
//-----------------------
KSVDragList::KSVDragList ( TQWidget* parent, const char* name )
- : KListView (parent, name),
+ : TDEListView (parent, name),
mItemToDrag (0L),
- mDragMenu (new KPopupMenu (this)),
- mDragCopyMenu (new KPopupMenu (this)),
- mDragMoveMenu (new KPopupMenu (this)),
+ mDragMenu (new TDEPopupMenu (this)),
+ mDragCopyMenu (new TDEPopupMenu (this)),
+ mDragMoveMenu (new TDEPopupMenu (this)),
mDisplayToolTips (true),
mCommonToolTips (true)
{
@@ -400,7 +400,7 @@ void KSVDragList::setDefaultIcon (const TQPixmap& icon)
void KSVDragList::clear ()
{
- KListView::clear();
+ TDEListView::clear();
clearRMList();
}
@@ -558,7 +558,7 @@ bool KSVDragList::acceptDrag (TQDropEvent* e) const
void KSVDragList::focusInEvent (TQFocusEvent* e)
{
- KListView::focusInEvent(e);
+ TDEListView::focusInEvent(e);
if (!currentItem())
setCurrentItem (firstChild());
diff --git a/ksysv/ksvdraglist.h b/ksysv/ksvdraglist.h
index 76ef598..c086f02 100644
--- a/ksysv/ksvdraglist.h
+++ b/ksysv/ksvdraglist.h
@@ -46,7 +46,7 @@ class TQPen;
class KSVAction;
class SimpleAction;
class KSVDragList;
-class KPopupMenu;
+class TDEPopupMenu;
class KSVConfig;
class KDLToolTip;
@@ -64,10 +64,10 @@ public:
Last
} Columns;
- KSVItem (KListView*);
+ KSVItem (TDEListView*);
KSVItem (const KSVItem&);
explicit KSVItem (KSVDragList*, const KSVData&);
- KSVItem (KListView* view, TQString file, TQString path, TQString label, TQ_INT8 nr );
+ KSVItem (TDEListView* view, TQString file, TQString path, TQString label, TQ_INT8 nr );
virtual ~KSVItem ();
virtual TQString key (int col, bool ascending) const;
@@ -149,7 +149,7 @@ private:
TQColor mChangedSelectedColor;
};
-class KSVDragList : public KListView
+class KSVDragList : public TDEListView
{
Q_OBJECT
@@ -175,9 +175,9 @@ public:
*/
inline bool isOrigin() const { return mOrigin; }
- inline KSVItem* currentItem() { return static_cast<KSVItem*> (KListView::currentItem()); }
+ inline KSVItem* currentItem() { return static_cast<KSVItem*> (TDEListView::currentItem()); }
- inline KSVItem* lastItem () { return static_cast<KSVItem*> (KListView::lastItem()); }
+ inline KSVItem* lastItem () { return static_cast<KSVItem*> (TDEListView::lastItem()); }
/**
* @return true if the insertion was successful.
@@ -248,9 +248,9 @@ private:
TQColor mChangedNormalColor;
TQColor mChangedSelectedColor;
- KPopupMenu* mDragMenu;
- KPopupMenu* mDragCopyMenu;
- KPopupMenu* mDragMoveMenu;
+ TDEPopupMenu* mDragMenu;
+ TDEPopupMenu* mDragCopyMenu;
+ TDEPopupMenu* mDragMoveMenu;
KDLToolTip* toolTip;
typedef enum { Copy, Move } DragAction;
diff --git a/ksysv/ksvlookandfeel.cpp b/ksysv/ksvlookandfeel.cpp
index 9c68cfb..3284107 100644
--- a/ksysv/ksvlookandfeel.cpp
+++ b/ksysv/ksvlookandfeel.cpp
@@ -55,7 +55,7 @@ KSVLookAndFeel::~KSVLookAndFeel()
*/
void KSVLookAndFeel::chooseNumberFont()
{
- KFontDialog::getFont (mNumberFont, false, this);
+ TDEFontDialog::getFont (mNumberFont, false, this);
setNumberFont (mNumberFont);
emit configChanged();
}
@@ -65,7 +65,7 @@ void KSVLookAndFeel::chooseNumberFont()
*/
void KSVLookAndFeel::chooseServiceFont()
{
- KFontDialog::getFont (mServiceFont, false, this);
+ TDEFontDialog::getFont (mServiceFont, false, this);
setServiceFont (mServiceFont);
emit configChanged();
}
diff --git a/kuser/editGroup.cpp b/kuser/editGroup.cpp
index 02fce6f..b9263b4 100644
--- a/kuser/editGroup.cpp
+++ b/kuser/editGroup.cpp
@@ -158,7 +158,7 @@ editGroup::editGroup(KU::KGroup *akg, bool samba, bool add,
if ( !mAdd ) cbsamba->setChecked( !( kg->getCaps() & KU::KGroup::Cap_Samba ) );
}
- m_list_in = new KListView(page);
+ m_list_in = new TDEListView(page);
m_list_in->setFullWidth(true); // Single column, full widget width.
m_list_in->addColumn(i18n("Users in Group"));
m_list_in->setSelectionMode( TQListView::Extended );
@@ -169,7 +169,7 @@ editGroup::editGroup(KU::KGroup *akg, bool samba, bool add,
TQPushButton *btdel = new TQPushButton(i18n("Remove ->"), vbox);
layout->addWidget( vbox, 8, 1 );
- m_list_notin = new KListView(page);
+ m_list_notin = new TDEListView(page);
m_list_notin->setFullWidth(true); // Single column, full widget width.
m_list_notin->addColumn(i18n("Users NOT in Group"));
m_list_notin->setSelectionMode(TQListView::Extended);
@@ -185,10 +185,10 @@ editGroup::editGroup(KU::KGroup *akg, bool samba, bool add,
user = kug->getUsers()[i];
TQString userName = user->getName();
if ( kg->lookup_user(userName) || user->getGID() == kg->getGID() ) {
- KListViewItem *item = new KListViewItem(m_list_in, userName);
+ TDEListViewItem *item = new TDEListViewItem(m_list_in, userName);
if ( user->getGID() == kg->getGID() ) item->setSelectable( false );
} else {
- new KListViewItem(m_list_notin, userName);
+ new TDEListViewItem(m_list_notin, userName);
}
}
@@ -224,7 +224,7 @@ void editGroup::addClicked()
if ( item->isSelected() ) {
name = item->text( 0 );
delete item;
- item = new KListViewItem( m_list_in, name );
+ item = new TDEListViewItem( m_list_in, name );
}
item = next;
}
@@ -241,7 +241,7 @@ void editGroup::delClicked()
if ( item->isSelected() ) {
name = item->text( 0 );
delete item;
- item = new KListViewItem( m_list_notin, name );
+ item = new TDEListViewItem( m_list_notin, name );
}
item = next;
}
diff --git a/kuser/editGroup.h b/kuser/editGroup.h
index 16e83cf..16a8ae4 100644
--- a/kuser/editGroup.h
+++ b/kuser/editGroup.h
@@ -51,7 +51,7 @@ private:
bool mSamba, mAdd;
bool ro;
KU::KGroup *kg;
- KListView *m_list_in,*m_list_notin;
+ TDEListView *m_list_in,*m_list_notin;
KLineEdit *legrpname;
KLineEdit *legid;
KComboBox *lerid;
diff --git a/kuser/kgroupvw.cpp b/kuser/kgroupvw.cpp
index 1eccf5c..c9df471 100644
--- a/kuser/kgroupvw.cpp
+++ b/kuser/kgroupvw.cpp
@@ -24,8 +24,8 @@
#include "kgroupvw.h"
-KGroupViewItem::KGroupViewItem(KListView *parent, KU::KGroup *aku)
- : KListViewItem(parent), mGroup(aku)
+KGroupViewItem::KGroupViewItem(TDEListView *parent, KU::KGroup *aku)
+ : TDEListViewItem(parent), mGroup(aku)
{
}
@@ -83,7 +83,7 @@ TQString KGroupViewItem::text(int num) const
KGroupView::KGroupView(TQWidget *parent, const char *name)
- : KListView( parent, name )
+ : TDEListView( parent, name )
{
setSelectionMode( TQListView::Extended );
}
@@ -95,7 +95,7 @@ KGroupView::~KGroupView()
void KGroupView::insertItem(KU::KGroup *aku)
{
KGroupViewItem *groupItem = new KGroupViewItem(this, aku);
- KListView::insertItem(groupItem);
+ TDEListView::insertItem(groupItem);
}
void KGroupView::removeItem(KU::KGroup *aku)
diff --git a/kuser/kgroupvw.h b/kuser/kgroupvw.h
index 69d53d2..0b29dab 100644
--- a/kuser/kgroupvw.h
+++ b/kuser/kgroupvw.h
@@ -27,10 +27,10 @@
#include "kgroup.h"
-class KGroupViewItem : public KListViewItem
+class KGroupViewItem : public TDEListViewItem
{
public:
- KGroupViewItem(KListView *parent, KU::KGroup *aku);
+ KGroupViewItem(TDEListView *parent, KU::KGroup *aku);
KU::KGroup *group() { return mGroup; }
private:
virtual TQString text ( int ) const;
@@ -39,7 +39,7 @@ private:
KU::KGroup *mGroup;
};
-class KGroupView : public KListView
+class KGroupView : public TDEListView
{
Q_OBJECT
diff --git a/kuser/kuservw.cpp b/kuser/kuservw.cpp
index b98495e..9fae9d5 100644
--- a/kuser/kuservw.cpp
+++ b/kuser/kuservw.cpp
@@ -24,8 +24,8 @@
#include "kuservw.h"
-KUserViewItem::KUserViewItem(KListView *parent, KU::KUser *aku)
- : KListViewItem(parent), mUser(aku)
+KUserViewItem::KUserViewItem(TDEListView *parent, KU::KUser *aku)
+ : TDEListViewItem(parent), mUser(aku)
{
}
@@ -53,7 +53,7 @@ void KUserViewItem::paintCell( TQPainter *p, const TQColorGroup &cg,
if ( mUser->getDisabled() )
_cg.setColor( TQColorGroup::Text, TDEGlobalSettings::visitedLinkColor() );
- KListViewItem::paintCell( p, _cg, column, width, alignment );
+ TDEListViewItem::paintCell( p, _cg, column, width, alignment );
_cg.setColor( TQColorGroup::Text, c );
}
@@ -81,7 +81,7 @@ TQString KUserViewItem::text(int num) const
}
KUserView::KUserView(TQWidget *parent, const char *name)
- : KListView( parent, name )
+ : TDEListView( parent, name )
{
setSelectionMode( TQListView::Extended );
}
@@ -92,7 +92,7 @@ KUserView::~KUserView()
void KUserView::insertItem(KU::KUser *aku) {
KUserViewItem *userItem = new KUserViewItem(this, aku);
- KListView::insertItem(userItem);
+ TDEListView::insertItem(userItem);
}
void KUserView::removeItem(KU::KUser *aku) {
diff --git a/kuser/kuservw.h b/kuser/kuservw.h
index 5977ad5..15068a6 100644
--- a/kuser/kuservw.h
+++ b/kuser/kuservw.h
@@ -27,10 +27,10 @@
#include "kuser.h"
-class KUserViewItem : public KListViewItem
+class KUserViewItem : public TDEListViewItem
{
public:
- KUserViewItem(KListView *parent, KU::KUser *aku);
+ KUserViewItem(TDEListView *parent, KU::KUser *aku);
KU::KUser *user() { return mUser; }
private:
virtual TQString text ( int ) const;
@@ -40,7 +40,7 @@ private:
KU::KUser *mUser;
};
-class KUserView : public KListView
+class KUserView : public TDEListView
{
Q_OBJECT
diff --git a/kuser/mainWidget.cpp b/kuser/mainWidget.cpp
index 0f3dfbd..046ed76 100644
--- a/kuser/mainWidget.cpp
+++ b/kuser/mainWidget.cpp
@@ -38,7 +38,7 @@
#include "selectconn.h"
#include "mainView.h"
-mainWidget::mainWidget(const char *name) : KMainWindow(0,name)
+mainWidget::mainWidget(const char *name) : TDEMainWindow(0,name)
{
md = new mainView(this);
@@ -75,37 +75,37 @@ void mainWidget::setupActions()
#define BarIconC(x) BarIcon(TQString::fromLatin1(x))
- (void) new KAction(i18n("&Add..."), TQIconSet(BarIconC("add_user")), 0, TQT_TQOBJECT(md),
+ (void) new TDEAction(i18n("&Add..."), TQIconSet(BarIconC("add_user")), 0, TQT_TQOBJECT(md),
TQT_SLOT(useradd()), actionCollection(), "add_user");
- (void) new KAction(i18n("&Edit..."), TQIconSet(BarIconC("edit_user")), 0, TQT_TQOBJECT(md),
+ (void) new TDEAction(i18n("&Edit..."), TQIconSet(BarIconC("edit_user")), 0, TQT_TQOBJECT(md),
TQT_SLOT(useredit()), actionCollection(), "edit_user");
- (void) new KAction(i18n("&Delete..."), TQIconSet(BarIconC("delete_user")), 0, TQT_TQOBJECT(md),
+ (void) new TDEAction(i18n("&Delete..."), TQIconSet(BarIconC("delete_user")), 0, TQT_TQOBJECT(md),
TQT_SLOT(userdel()), actionCollection(), "delete_user");
- (void) new KAction(i18n("&Set Password..."),
+ (void) new TDEAction(i18n("&Set Password..."),
0, TQT_TQOBJECT(md), TQT_SLOT(setpwd()), actionCollection(), "set_password_user");
- (void) new KAction(i18n("&Add..."), TQIconSet(BarIconC("add_group")), 0, TQT_TQOBJECT(md),
+ (void) new TDEAction(i18n("&Add..."), TQIconSet(BarIconC("add_group")), 0, TQT_TQOBJECT(md),
TQT_SLOT(grpadd()), actionCollection(), "add_group");
- (void) new KAction(i18n("&Edit..."), TQIconSet(BarIconC("edit_group")), 0, TQT_TQOBJECT(md),
+ (void) new TDEAction(i18n("&Edit..."), TQIconSet(BarIconC("edit_group")), 0, TQT_TQOBJECT(md),
TQT_SLOT(grpedit()), actionCollection(), "edit_group");
- (void) new KAction(i18n("&Delete"), TQIconSet(BarIconC("delete_group")), 0, TQT_TQOBJECT(md),
+ (void) new TDEAction(i18n("&Delete"), TQIconSet(BarIconC("delete_group")), 0, TQT_TQOBJECT(md),
TQT_SLOT(grpdel()), actionCollection(), "delete_group");
- (void) new KAction(i18n("&Reload"), TQIconSet(BarIconC("reload")), 0, TQT_TQOBJECT(this),
+ (void) new TDEAction(i18n("&Reload"), TQIconSet(BarIconC("reload")), 0, TQT_TQOBJECT(this),
TQT_SLOT(reload()), actionCollection(), "reload");
#undef BarIconC
- (void) new KAction(i18n("&Select Connection..."),
+ (void) new TDEAction(i18n("&Select Connection..."),
0, TQT_TQOBJECT(this),
TQT_SLOT(selectconn()), actionCollection(), "select_conn");
- mShowSys = new KToggleAction(i18n("Show System Users/Groups"),
+ mShowSys = new TDEToggleAction(i18n("Show System Users/Groups"),
0, 0, TQT_TQOBJECT(this),
TQT_SLOT(showSys()), actionCollection(), "show_sys");
mShowSys->setCheckedState(i18n("Hide System Users/Groups"));
diff --git a/kuser/mainWidget.h b/kuser/mainWidget.h
index 78724af..dbe2b34 100644
--- a/kuser/mainWidget.h
+++ b/kuser/mainWidget.h
@@ -25,9 +25,9 @@
class SelectConn;
class mainView;
-class KToggleAction;
+class TDEToggleAction;
-class mainWidget : public KMainWindow {
+class mainWidget : public TDEMainWindow {
Q_OBJECT
public:
@@ -48,7 +48,7 @@ protected slots:
void reload();
private:
- KToggleAction *mShowSys;
+ TDEToggleAction *mShowSys;
mainView *md;
SelectConn *sc;
diff --git a/kuser/propdlg.cpp b/kuser/propdlg.cpp
index 40e8085..8ce7e6a 100644
--- a/kuser/propdlg.cpp
+++ b/kuser/propdlg.cpp
@@ -320,7 +320,7 @@ void propdlg::initDlg()
TQFrame *frame = addPage(i18n("Groups"));
TQGridLayout *layout = new TQGridLayout(frame, 2, 2, marginHint(), spacingHint());
- lstgrp = new KListView(frame);
+ lstgrp = new TDEListView(frame);
lstgrp->setFullWidth(true); // Single column, full widget width.
lstgrp->addColumn( i18n("Groups") );
if ( ro ) lstgrp->setSelectionMode( TQListView::NoSelection );
diff --git a/kuser/propdlg.h b/kuser/propdlg.h
index 7ecc396..a94ddc4 100644
--- a/kuser/propdlg.h
+++ b/kuser/propdlg.h
@@ -101,7 +101,7 @@ protected:
TQString newpass;
time_t lstchg;
- KListView *lstgrp;
+ TDEListView *lstgrp;
TQPushButton *pbsetpwd;
diff --git a/secpolicy/secpolicywin.cpp b/secpolicy/secpolicywin.cpp
index f74c4e9..9404f19 100644
--- a/secpolicy/secpolicywin.cpp
+++ b/secpolicy/secpolicywin.cpp
@@ -35,14 +35,14 @@
#include "secpolicywin.h"
SecPolicyWin::SecPolicyWin(const char *name)
- : KMainWindow(0,name)
+ : TDEMainWindow(0,name)
{
view = new PamView(this);
setCentralWidget(view);
KMenuBar *mBar = menuBar();
TQPopupMenu *fileMenu = new TQPopupMenu(this);
- fileMenu->insertItem(i18n("&Quit"), kapp, TQT_SLOT(closeAllWindows()), KStdAccel::shortcut(KStdAccel::Quit));
+ fileMenu->insertItem(i18n("&Quit"), kapp, TQT_SLOT(closeAllWindows()), TDEStdAccel::shortcut(TDEStdAccel::Quit));
mBar->insertItem(i18n("&File"), fileMenu);
connect(kapp, TQT_SIGNAL(lastWindowClosed()), kapp, TQT_SLOT(quit()));
diff --git a/secpolicy/secpolicywin.h b/secpolicy/secpolicywin.h
index 078fafa..3284473 100644
--- a/secpolicy/secpolicywin.h
+++ b/secpolicy/secpolicywin.h
@@ -29,7 +29,7 @@
class PamView;
-class SecPolicyWin : public KMainWindow
+class SecPolicyWin : public TDEMainWindow
{
public:
SecPolicyWin(const char *name = 0);
diff --git a/kcron/ktapp.cpp b/kcron/ktapp.cpp
index 9f00362..98e6603 100644
--- a/kcron/ktapp.cpp
+++ b/kcron/ktapp.cpp
@@ -33,7 +33,7 @@
const int KTApp::statusMessage (1001);
-KTApp::KTApp() : KMainWindow(0)
+KTApp::KTApp() : TDEMainWindow(0)
{
config=kapp->config();
@@ -56,8 +56,8 @@ KTApp::KTApp() : KMainWindow(0)
view->disableIcons();
//Connections
- KPopupMenu *editMenu = static_cast<KPopupMenu*>(guiFactory()->container("edit", this));
- KPopupMenu *settingsMenu = static_cast<KPopupMenu*>(guiFactory()->container("settings", this));
+ TDEPopupMenu *editMenu = static_cast<TDEPopupMenu*>(guiFactory()->container("edit", this));
+ TDEPopupMenu *settingsMenu = static_cast<TDEPopupMenu*>(guiFactory()->container("settings", this));
connect(editMenu,TQT_SIGNAL(highlighted(int)),this,TQT_SLOT(statusEditCallback(int)));
connect(settingsMenu,TQT_SIGNAL(highlighted(int)),this,TQT_SLOT(statusSettingsCallback(int)));
@@ -128,16 +128,16 @@ void KTApp::setupActions()
KStdAction::cut(TQT_TQOBJECT(this), TQT_SLOT(slotEditCut()), actionCollection());
KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(slotEditCopy()), actionCollection());
KStdAction::paste(TQT_TQOBJECT(this), TQT_SLOT(slotEditPaste()), actionCollection());
- (void)new KAction(i18n("&New..."), KStdAccel::openNew(), TQT_TQOBJECT(this),TQT_SLOT(slotEditNew()),actionCollection(),"edit_new");
- //I don't like this KStdAccel::open() for modifying, but I'm just porting this to xmlui
- (void)new KAction(i18n("M&odify..."), KStdAccel::open(), TQT_TQOBJECT(this),TQT_SLOT(slotEditModify()),actionCollection(),"edit_modify");
- (void)new KAction(i18n("&Delete"), 0, TQT_TQOBJECT(this),TQT_SLOT(slotEditDelete()),actionCollection(),"edit_delete");
- (void)new KAction(i18n("&Enabled"), 0, TQT_TQOBJECT(this),TQT_SLOT(slotEditEnable()),actionCollection(),"edit_enable");
- (void)new KAction(i18n("&Run Now"), 0, TQT_TQOBJECT(this),TQT_SLOT(slotEditRunNow()),actionCollection(),"edit_run");
+ (void)new TDEAction(i18n("&New..."), TDEStdAccel::openNew(), TQT_TQOBJECT(this),TQT_SLOT(slotEditNew()),actionCollection(),"edit_new");
+ //I don't like this TDEStdAccel::open() for modifying, but I'm just porting this to xmlui
+ (void)new TDEAction(i18n("M&odify..."), TDEStdAccel::open(), TQT_TQOBJECT(this),TQT_SLOT(slotEditModify()),actionCollection(),"edit_modify");
+ (void)new TDEAction(i18n("&Delete"), 0, TQT_TQOBJECT(this),TQT_SLOT(slotEditDelete()),actionCollection(),"edit_delete");
+ (void)new TDEAction(i18n("&Enabled"), 0, TQT_TQOBJECT(this),TQT_SLOT(slotEditEnable()),actionCollection(),"edit_enable");
+ (void)new TDEAction(i18n("&Run Now"), 0, TQT_TQOBJECT(this),TQT_SLOT(slotEditRunNow()),actionCollection(),"edit_run");
//Settings menu
- (void)new KAction(i18n("Show &Toolbar"), 0, TQT_TQOBJECT(this),TQT_SLOT(slotViewToolBar()),actionCollection(),"show_toolbar");
- (void)new KAction(i18n("Show &Statusbar"), 0, TQT_TQOBJECT(this),TQT_SLOT(slotViewStatusBar()),actionCollection(),"show_statusbar");
+ (void)new TDEAction(i18n("Show &Toolbar"), 0, TQT_TQOBJECT(this),TQT_SLOT(slotViewToolBar()),actionCollection(),"show_toolbar");
+ (void)new TDEAction(i18n("Show &Statusbar"), 0, TQT_TQOBJECT(this),TQT_SLOT(slotViewStatusBar()),actionCollection(),"show_statusbar");
}
@@ -160,7 +160,7 @@ void KTApp::saveOptions()
void KTApp::readOptions()
{
config->setGroup(TQString("General Options"));
- KPopupMenu *settingsMenu = static_cast<KPopupMenu*>(guiFactory()->container("settings", this));
+ TDEPopupMenu *settingsMenu = static_cast<TDEPopupMenu*>(guiFactory()->container("settings", this));
// bar status settings
bool bViewToolbar = config->readBoolEntry(TQString("Show Toolbar"), true);
@@ -174,10 +174,10 @@ void KTApp::readOptions()
statusBar()->hide();
// bar position settings
- KToolBar::BarPosition tool_bar_pos;
- tool_bar_pos=(KToolBar::BarPosition)
+ TDEToolBar::BarPosition tool_bar_pos;
+ tool_bar_pos=(TDEToolBar::BarPosition)
config->readNumEntry(TQString("ToolBarPos"),
- KToolBar::Top);
+ TDEToolBar::Top);
toolBar()->setBarPos(tool_bar_pos);
@@ -276,7 +276,7 @@ void KTApp::slotFileQuit()
void KTApp::slotEdit(const TQPoint& qp)
{
- KPopupMenu *editMenu = static_cast<KPopupMenu*>(guiFactory()->container("edit", this));
+ TDEPopupMenu *editMenu = static_cast<TDEPopupMenu*>(guiFactory()->container("edit", this));
editMenu->exec(qp, 0);
}
@@ -325,7 +325,7 @@ void KTApp::slotEditDelete()
void KTApp::slotEditEnable()
{
- KPopupMenu *editMenu = static_cast<KPopupMenu*>(guiFactory()->container("edit", this));
+ TDEPopupMenu *editMenu = static_cast<TDEPopupMenu*>(guiFactory()->container("edit", this));
if (editMenu->isItemChecked(editMenu->idAt(8)))
{
slotStatusMsg(i18n("Disabling entry..."));
@@ -355,7 +355,7 @@ void KTApp::slotViewToolBar()
else
toolBar()->show();
- KPopupMenu *settingsMenu = static_cast<KPopupMenu*>(guiFactory()->container("settings", this));
+ TDEPopupMenu *settingsMenu = static_cast<TDEPopupMenu*>(guiFactory()->container("settings", this));
settingsMenu->setItemChecked(settingsMenu->idAt(0),toolBar()->isVisible());
slotStatusMsg(i18n("Ready."));
@@ -368,7 +368,7 @@ void KTApp::slotViewStatusBar()
else
statusBar()->show();
- KPopupMenu *settingsMenu = static_cast<KPopupMenu*>(guiFactory()->container("settings", this));
+ TDEPopupMenu *settingsMenu = static_cast<TDEPopupMenu*>(guiFactory()->container("settings", this));
settingsMenu->setItemChecked(settingsMenu->idAt(1),statusBar()->isVisible());
slotStatusMsg(i18n("Ready."));
@@ -388,7 +388,7 @@ void KTApp::slotStatusHelpMsg(const TQString & text)
void KTApp::statusEditCallback(int id_)
{
- KPopupMenu *editMenu = static_cast<KPopupMenu*>(guiFactory()->container("edit", this));
+ TDEPopupMenu *editMenu = static_cast<TDEPopupMenu*>(guiFactory()->container("edit", this));
int index = editMenu->indexOf(id_);
switch (index) {
case menuEditNew:
@@ -414,7 +414,7 @@ void KTApp::statusEditCallback(int id_)
void KTApp::statusSettingsCallback(int id_)
{
- KPopupMenu *settingsMenu = static_cast<KPopupMenu*>(guiFactory()->container("settings", this));
+ TDEPopupMenu *settingsMenu = static_cast<TDEPopupMenu*>(guiFactory()->container("settings", this));
int index = settingsMenu->indexOf(id_);
switch (index) {
case menuSettingsShowToolBar:
@@ -456,7 +456,7 @@ void KTApp::slotEnableRunNow(bool state)
void KTApp::slotEnableEnabled(bool state)
{
- KPopupMenu *editMenu = static_cast<KPopupMenu*>(guiFactory()->container("edit", this));
+ TDEPopupMenu *editMenu = static_cast<TDEPopupMenu*>(guiFactory()->container("edit", this));
editMenu->setItemChecked(editMenu->idAt(8),state);
}
diff --git a/knetwortdeconf/knetwortdeconf/knetwortdeconf.cpp b/knetwortdeconf/knetwortdeconf/knetwortdeconf.cpp
index 3a01a60..4e1bd9b 100644
--- a/knetwortdeconf/knetwortdeconf/knetwortdeconf.cpp
+++ b/knetwortdeconf/knetwortdeconf/knetwortdeconf.cpp
@@ -38,9 +38,9 @@ KNetworkConf::KNetworkConf(TQWidget *parent, const char *name) : DCOPObject("KNe
connect(config,TQT_SIGNAL(readyLoadingNetworkInfo()),this,TQT_SLOT(enableSignals()));
connect(config, TQT_SIGNAL(setReadOnly(bool)),this,TQT_SLOT(setReadOnlySlot(bool)));
connect(klvCardList,
- TQT_SIGNAL(contextMenu(KListView*,TQListViewItem*,const TQPoint&)),
+ TQT_SIGNAL(contextMenu(TDEListView*,TQListViewItem*,const TQPoint&)),
this,
- TQT_SLOT(showInterfaceContextMenuSlot(KListView*,TQListViewItem*, const TQPoint&)));
+ TQT_SLOT(showInterfaceContextMenuSlot(TDEListView*,TQListViewItem*, const TQPoint&)));
// Register with DCOP - No longer needed as now we are a kcontrol module?
if ( !kapp->dcopClient()->isRegistered() ) {
@@ -634,7 +634,7 @@ void KNetworkConf::saveInfoSlot(){
}
}
/** Creates a TQStringList with the IP addresses contained in the TQListBox of name servers. */
-TQStringList KNetworkConf::getNamserversList(KListBox * serverList){
+TQStringList KNetworkConf::getNamserversList(TDEListBox * serverList){
TQStringList list;
for (unsigned i = 0; i < serverList->count(); i++)
{
@@ -642,8 +642,8 @@ TQStringList KNetworkConf::getNamserversList(KListBox * serverList){
}
return list;
}
-/** Creates a TQPtrList<KKownHostInfo> with the info contained in the KListView of name servers. */
-TQPtrList<KKnownHostInfo> KNetworkConf::getKnownHostsList(KListView * hostsList){
+/** Creates a TQPtrList<KKownHostInfo> with the info contained in the TDEListView of name servers. */
+TQPtrList<KKnownHostInfo> KNetworkConf::getKnownHostsList(TDEListView * hostsList){
TQPtrList<KKnownHostInfo> list;
TQListViewItem *it = hostsList->firstChild();
for (int i = 0; i < hostsList->childCount(); i++)
@@ -860,7 +860,7 @@ void KNetworkConf::disableInterfaceSlot()
changeDeviceState(dev->getDeviceName(),DEVICE_UP);
}
/** Adds a new host to the KListView that has the known hosts. */
void KNetworkConf::addKnownHostSlot(){
KAddKnownHostDlg dlg(this,0);
dlg.setCaption(i18n("Add New Static Host"));
@@ -977,9 +977,9 @@ void KNetworkConf::setReadOnlySlot(bool state)
}
/*Shows a context menu when right-clicking in the interface list*/
-void KNetworkConf::showInterfaceContextMenuSlot(KListView* lv, TQListViewItem* lvi, const TQPoint& pt)
+void KNetworkConf::showInterfaceContextMenuSlot(TDEListView* lv, TQListViewItem* lvi, const TQPoint& pt)
{
- KPopupMenu *context = new KPopupMenu( this );
+ TDEPopupMenu *context = new TDEPopupMenu( this );
TQ_CHECK_PTR( context );
context->insertItem( "&Enable Interface", this, TQT_SLOT(enableInterfaceSlot()));
context->insertItem( "&Disable Interface", this, TQT_SLOT(disableInterfaceSlot()));
@@ -860,7 +860,7 @@ void KNetworkConf::disableInterfaceSlot()
changeDeviceState(dev->getDeviceName(),DEVICE_UP);
}
-/** Adds a new host to the KListView that has the known hosts. */
+/** Adds a new host to the TDEListView that has the known hosts. */
void KNetworkConf::addKnownHostSlot(){
KAddKnownHostDlg dlg(this,0);
diff --git a/knetwortdeconf/knetwortdeconf/knetwortdeconf.h b/knetwortdeconf/knetwortdeconf/knetwortdeconf.h
index ce1bf15..5948678 100644
--- a/knetwortdeconf/knetwortdeconf/knetwortdeconf.h
+++ b/knetwortdeconf/knetwortdeconf/knetwortdeconf.h
@@ -103,9 +103,9 @@ class KNetworkConf : public KNetworkConfDlg, virtual public KNetworkConfIface
KNetworkInterface * getDeviceInfo(TQString device);
TQString getDeviceName(TQString ipAddr);
/** Creates a TQStringList with the IP addresses contained in the TQListBox of name servers. */
- TQStringList getNamserversList(KListBox * serverList);
-/** Creates a TQPtrList<KKownHostInfo> with the info contained in the KListView of name servers. */
- TQPtrList<KKnownHostInfo> getKnownHostsList(KListView * hostsList);
+ TQStringList getNamserversList(TDEListBox * serverList);
+/** Creates a TQPtrList<KKownHostInfo> with the info contained in the TDEListView of name servers. */
+ TQPtrList<KKnownHostInfo> getKnownHostsList(TDEListView * hostsList);
TQString currentDevice;
KRoutingInfo *routingInfo;
KDNSInfo *dnsInfo;
@@ -176,7 +176,7 @@ class KNetworkConf : public KNetworkConfDlg, virtual public KNetworkConfIface
/** Sets the TQPushButton::autoResize() in true for all buttons. */
void makeButtonsResizeable();
/** Adds a new host to the KListView that has the known hosts. */
void addKnownHostSlot();
void aboutSlot();
/** Edits the info about a known host. */
@@ -193,7 +193,7 @@ class KNetworkConf : public KNetworkConfDlg, virtual public KNetworkConfIface
bool isDeviceActive(const TQString &device, const TQString &ifconfigOutput);
/*Shows a context menu when right-clicking in the interface list*/
- void showInterfaceContextMenuSlot(KListView*, TQListViewItem*, const TQPoint&);
+ void showInterfaceContextMenuSlot(TDEListView*, TQListViewItem*, const TQPoint&);
/** Enable some signals in the GUI that need to be enabled *after* the loading of the network info is done.*/
void enableSignals ();
@@ -176,7 +176,7 @@ class KNetworkConf : public KNetworkConfDlg, virtual public KNetworkConfIface
/** Sets the TQPushButton::autoResize() in true for all buttons. */
void makeButtonsResizeable();
- /** Adds a new host to the KListView that has the known hosts. */
+ /** Adds a new host to the TDEListView that has the known hosts. */
void addKnownHostSlot();
void aboutSlot();